%define targets sifive_unleashed sifive_unmatched
%define qemu qemu-riscv64_smode

Name: u-boot-sifive
Version: 2024.01
Release: alt3

Summary: Das U-Boot

License: GPL-2.0-or-later
Group: System/Kernel and hardware
Url: http://www.denx.de/wiki/U-Boot

ExclusiveArch: riscv64

Source: %name-%version.tar
Patch:  %name-%version-%release.patch


BuildRequires: ccache
BuildRequires: bc dtc >= 1.4 flex libssl-devel
BuildRequires: python3(pkg_resources) python3(libfdt)

# Forbid silent rebuilds with newer OpenSBI
BuildRequires: opensbi = 1.4


%description
Boot loader for embedded boards based on PowerPC, ARM, MIPS and several
other processors, which can be installed in a boot ROM and used to
initialize and test the hardware or to download and run application code.
This package supports SiFive Unleashed and Unmatched boards.

%package -n u-boot-qemu
Release: %release.rv64
Summary: Das U-Boot
Group: System/Kernel and hardware
BuildArch: noarch

%description -n u-boot-qemu
This package contains U-Boot image for QEMU virt machine.

%prep
%setup
%autopatch -p1

%build

mkdir build
%make_build \
    HOSTCC="ccache gcc" \
    CC="ccache ${CROSS_COMPILE:-}gcc" \
    DTC="$(which dtc)" \
    KCFLAGS="-O2 -falign-functions=64" \
    V=1 O=build %{qemu}_defconfig all

install -pm0644 -D build/u-boot.bin out/%qemu/u-boot.bin
rm -rf build

OPENSBI=%_datadir/opensbi/generic/firmware/fw_dynamic.bin
for board in %targets; do
    mkdir build
    %make_build \
        HOSTCC="ccache gcc" \
        CC="ccache ${CROSS_COMPILE:-}gcc" \
        DTC="$(which dtc)" \
        KCFLAGS="-O2 -falign-functions=64" \
        V=1 O=build OPENSBI=$OPENSBI ${board}_defconfig all
    install -pm0644 -D build/u-boot.itb out/${board}/u-boot.itb
    install -pm0644 -D build/spl/u-boot-spl.bin  out/${board}/u-boot-spl.bin
    rm -rf build
done

%install
cd out
for board in %qemu %targets; do
    mkdir -p %buildroot%_datadir/u-boot/${board}/
    cp ${board}/* %buildroot%_datadir/u-boot/${board}/
done

%files
%doc README doc/board/sifive
%_datadir/u-boot/*
%exclude %_datadir/u-boot/%qemu

%files -n u-boot-qemu
%doc README
%_datadir/u-boot/%qemu/u-boot.bin

%changelog
* Wed Jan 24 2024 Ivan A. Melnikov <iv@altlinux.org> 2024.01-alt3
- Build with  -falign-functions=64 (fixes boot on Unmatched).

* Tue Jan 16 2024 Ivan A. Melnikov <iv@altlinux.org> 2024.01-alt2
- Fix SPL serial output for SiFive Unleashed

* Wed Jan 10 2024 Ivan A. Melnikov <iv@altlinux.org> 2024.01-alt1
- 2024.01
- use OpenSBI 1.4

* Wed Jul 26 2023 Ivan A. Melnikov <iv@altlinux.org> 2023.07.02-alt1
- 2023.07.02
- use OpenSBI 1.3.1

* Mon May 22 2023 Andrew Guschin <guschin@altlinux.org> 2023.04-alt1
- 2023.04

* Thu Jan 19 2023 Ivan A. Melnikov <iv@altlinux.org> 2023.01-alt1
- 2023.01

* Mon Jan 09 2023 Ivan A. Melnikov <iv@altlinux.org> 2022.10-alt4
- Rebuild with opensbi 1.2-alt2

* Fri Nov 18 2022 Ivan A. Melnikov <iv@altlinux.org> 2022.10-alt3
- Fix build with binutils 2.38
- Add 'poweroff' command to u-boot CLI on unmatched
- Minor spec improvements

* Thu Oct 20 2022 Ivan A. Melnikov <iv@altlinux.org> 2022.10-alt2
- sifive: search for DTBs in the default location
  (in sync with recent kernel-image-un-def update)
- package sifive boards documentation

* Wed Oct 05 2022 Ivan A. Melnikov <iv@altlinux.org> 2022.10-alt1
- Update to 2022.10

* Tue Aug 30 2022 Ivan A. Melnikov <iv@altlinux.org> 2022.07-alt1
- Update to 2022.07

* Tue Jan 25 2022 Dmitry Terekhin <jqt4@altlinux.org> 2022.01-alt2
- Load FDT from any partition on boot device.
- Load FDT from /boot/dtb/ as usual in Alt.

* Tue Jan 18 2022 Dmitry Terekhin <jqt4@altlinux.org> 2022.01-alt1
- Update to 2022.01.
- Building for Unleashed, Unmatched and QEmu from common sources.
- Use OpenSBI dynamic payload inside U-Boot.

* Thu May 20 2021 Nikita Ermakov <arei@altlinux.org> 2021.04-alt2
- Use fdtfile environment variable.

* Tue May 18 2021 Nikita Ermakov <arei@altlinux.org> 2021.04-alt1
- Update to 2021.04.

* Fri Nov 20 2020 Nikita Ermakov <arei@altlinux.org> 2020.10-alt1
- Update to 2020.10
- Set the fdtfile to the right DTB name.

* Mon Mar  2 2020 Nikita Ermakov <arei@altlinux.org> 2020.04.rc3-alt1
- Initial build for ALT Linux Sisyphus.
